generate_test_frontends.py
==========================

`View code on Github <https://github.com/activist-org/i18n-check/blob/main/src/i18n_check/cli/generate_test_frontends.py>`_

.. automodule:: i18n_check.cli.generate_test_frontends
    :members:
    :private-members:
